epic-kitchens
=============

`EPIC Kitchens`_ is an egocentric vision dataset, visit the website to
find out more.

In addition to the dataset, we provide a python library for performing
common tasks on the dataset.

Have a look at `EPIC-mini`_ for example usage.


.. toctree::
   :maxdepth: 3

   epic_kitchens.rst
   cli_tools.rst

.. _`EPIC Kitchens`: https://epic-kitchens.github.io
.. _`EPIC-mini`: https://github.com/epic-kitchens/epic-mini
